@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "2d1642ea4e08d76f16ed47e0e00f4ea7e155e074",
-  "branchName": "release-client-6.0.x",
-  "buildTime": "2024-05-23 08:08:24 GMT",
-  "buildVersion": "1.0.396",
+  "commitId": "857a225a157994ba7899d29493ef7f60aff453f7",
+  "branchName": "release-client-6.x",
+  "buildTime": "2024-06-14 06:47:38 GMT",
+  "buildVersion": "1.0.422",
   "css": [
-    "@zoom/client-calendar-dev/static/css/chunk-vendors.974eca6e.css",
-    "@zoom/client-calendar-dev/static/css/app.accf4c46.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.f0f0dc24.css",
+    "@zoom/client-scheduler/static/css/index.ef4f5c13.css"
   ],
   "js": [
-    "@zoom/client-calendar-dev/static/js/chunk-vendors.022f4ebd.js",
-    "@zoom/client-calendar-dev/static/js/app.777c55fb.js"
+    "@zoom/client-scheduler/chunk-vendors.0a656d4cd47956d29c87.js",
+    "@zoom/client-scheduler/index.0a656d4cd47956d29c87.js"
   ],
-  "key": "@zoom/client-calendar-dev"
+  "key": "clientSchedulerResource"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
